@@ -1,16 +1,15 @@
 //! This module provides bindings to for submitting jobs to and retrieving them from
 //! Rigetti QPUs using the QCS API.
 
-use std::{fmt, time::Duration};
+use std::{convert::TryFrom, fmt, time::Duration};
 
 use cached::proc_macro::cached;
 use derive_builder::Builder;
-use qcs_api_client_common::configuration::RefreshError;
+use qcs_api_client_common::configuration::TokenError;
 #[cfg(feature = "grpc-web")]
-use qcs_api_client_grpc::channel::wrap_channel_with_grpc_web;
-pub use qcs_api_client_grpc::channel::Error as GrpcError;
+use qcs_api_client_grpc::tonic::wrap_channel_with_grpc_web;
+pub use qcs_api_client_grpc::tonic::Error as GrpcError;
 use qcs_api_client_grpc::{
-    channel::{parse_uri, wrap_channel_with, wrap_channel_with_retry},
     get_channel_with_timeout,
     models::controller::{
         controller_job_execution_result, data_value::Value, ControllerJobExecutionResult,
@@ -22,6 +21,7 @@ use qcs_api_client_grpc::{
         CancelControllerJobsRequest, ExecuteControllerJobRequest,
         ExecutionOptions as InnerApiExecutionOptions, GetControllerJobResultsRequest,
     },
+    tonic::{parse_uri, wrap_channel_with, wrap_channel_with_retry},
 };
 pub use qcs_api_client_openapi::apis::Error as OpenApiError;
 use qcs_api_client_openapi::apis::{
@@ -302,16 +302,18 @@ pub async fn retrieve_results(
         .ok_or_else(|| GrpcClientError::ResponseEmpty("Job Execution Results".into()))
         .map_err(QpuApiError::from)
         .and_then(
-            |result| match controller_job_execution_result::Status::from_i32(result.status) {
-                Some(controller_job_execution_result::Status::Success) => Ok(result),
-                status => Err(QpuApiError::JobExecutionFailed {
-                    status: status
-                        .map_or("UNDEFINED", |status| status.as_str_name())
-                        .to_string(),
+            |result| match controller_job_execution_result::Status::try_from(result.status) {
+                Ok(controller_job_execution_result::Status::Success) => Ok(result),
+                Ok(status) => Err(QpuApiError::JobExecutionFailed {
+                    status: status.as_str_name().to_string(),
                     message: result
                         .status_message
                         .unwrap_or("No message provided.".to_string()),
                 }),
+                Err(s) => Err(QpuApiError::InvalidJobStatus {
+                    status: result.status,
+                    message: s.to_string(),
+                }),
             },
         )
 }
@@ -642,7 +644,7 @@ async fn get_default_endpoint(
 pub enum QpuApiError {
     /// Error due to a bad gRPC configuration
     #[error("Error configuring gRPC request: {0}")]
-    GrpcError(#[from] GrpcError<RefreshError>),
+    GrpcError(#[from] GrpcError<TokenError>),
 
     /// Error due to missing gRPC endpoint for endpoint ID
     #[error("Missing gRPC endpoint for endpoint ID: {0}")]
@@ -688,4 +690,15 @@ pub enum QpuApiError {
         /// The message associated with the failed job.
         message: String,
     },
+
+    /// Error that can occur if a numeric status identifier cannot be converted
+    /// into a known status type.
+    #[error("The request returned an invalid status: {status}. {message}")]
+    InvalidJobStatus {
+        /// The numeric status identifier.
+        status: i32,
+        /// The message describing the failure to convert the numeric status
+        /// identifier into a known status type.
+        message: String,
+    },
 }
