@@ -1,6 +1,6 @@
 use std::{collections::HashMap, num::NonZeroU16};
 
-use super::{PyQvmOptions, QvmClient, RustQvmError};
+use super::{PyQvmOptions, RustQvmError};
 use crate::{py_sync::py_function_sync_async, register_data::PyRegisterData};
 
 use pyo3::{
@@ -51,7 +51,6 @@ py_function_sync_async! {
     #[pyfunction]
     #[pyo3(signature = (client, options = None))]
     async fn get_version_info(client: super::PyQvmClient, options: Option<PyQvmOptions>) -> PyResult<String> {
-        let QvmClient::Http(client) = client.inner;
         client.get_version_info(options.unwrap_or_default().as_inner())
             .await
             .map_err(RustQvmError::from)
@@ -139,14 +138,15 @@ py_wrap_data_struct! {
 impl_repr!(PyMultishotResponse);
 
 py_function_sync_async! {
+    #[pyo3_opentelemetry::pypropagate]
     #[pyfunction]
     #[pyo3(signature = (request, client, options = None))]
+    #[tracing::instrument(skip_all)]
     async fn run(
         request: PyMultishotRequest,
         client: super::PyQvmClient,
         options: Option<PyQvmOptions>,
     ) -> PyResult<PyMultishotResponse> {
-        let QvmClient::Http(client) = client.inner;
         client.run(request.as_inner(), options.unwrap_or_default().as_inner())
             .await
             .map_err(RustQvmError::from)
@@ -202,10 +202,11 @@ impl PyMultishotMeasureRequest {
 }
 
 py_function_sync_async! {
+    #[pyo3_opentelemetry::pypropagate]
     #[pyfunction]
     #[pyo3(signature = (request, client, options = None))]
+    #[tracing::instrument(skip_all)]
     async fn run_and_measure(request: PyMultishotMeasureRequest, client: super::PyQvmClient, options: Option<PyQvmOptions>) -> PyResult<Vec<Vec<i64>>> {
-        let QvmClient::Http(client) = client.inner;
         client.run_and_measure(request.as_inner(), options.unwrap_or_default().as_inner())
             .await
             .map_err(RustQvmError::from)
@@ -235,10 +236,11 @@ impl PyExpectationRequest {
 }
 
 py_function_sync_async! {
+    #[pyo3_opentelemetry::pypropagate]
     #[pyfunction]
     #[pyo3(signature = (request, client, options = None))]
+    #[tracing::instrument(skip_all)]
     async fn measure_expectation(request: PyExpectationRequest, client: super::PyQvmClient, options: Option<PyQvmOptions>) -> PyResult<Vec<f64>> {
-        let QvmClient::Http(client) = client.inner;
         client.measure_expectation(request.as_inner(), options.unwrap_or_default().as_inner())
             .await
             .map_err(RustQvmError::from)
@@ -275,10 +277,11 @@ impl PyWavefunctionRequest {
 }
 
 py_function_sync_async! {
+    #[pyo3_opentelemetry::pypropagate]
     #[pyfunction]
     #[pyo3(signature = (request, client, options = None))]
+    #[tracing::instrument(skip_all)]
     async fn get_wavefunction(request: PyWavefunctionRequest, client: super::PyQvmClient, options: Option<PyQvmOptions>) -> PyResult<Vec<u8>> {
-        let QvmClient::Http(client) = client.inner;
         client.get_wavefunction(request.as_inner(), options.unwrap_or_default().as_inner())
             .await
             .map_err(RustQvmError::from)
